@@ -27,14 +27,18 @@
 #include <stdlib.h>
 
 /* for GtkText et all */
+#ifndef GTK_ENABLE_BROKEN
 #define GTK_ENABLE_BROKEN
+#endif
+#ifdef GTK_DISABLE_DEPRECATED
+#undef GTK_DISABLE_DEPRECATED
+#endif
 #include <gtk/gtk.h>
 
 #include <glade/glade.h>
 #include <glade/glade-build.h>
 #include <glade/glade-private.h>
 
-
 #define INT(s)   (strtol ((s), NULL, 0))
 #define BOOL(s)  (g_ascii_tolower (*(s)) == 't' || g_ascii_tolower (*(s)) == 'y' || INT (s))
 #define FLOAT(s) (g_strtod ((s), NULL))
@@ -68,6 +72,22 @@ set_tooltip(GladeXML *xml, GtkWidget *widget,
     gtk_tooltips_set_tip(xml->priv->tooltips, widget, prop_value, NULL);
 }
 
+static void
+set_has_default(GladeXML *xml, GtkWidget *widget,
+		const gchar *prop_name, const gchar *prop_value)
+{
+    if (BOOL(prop_value))
+	xml->priv->default_widget = widget;
+}
+
+static void
+set_has_focus(GladeXML *xml, GtkWidget *widget,
+	      const gchar *prop_name, const gchar *prop_value)
+{
+    if (BOOL(prop_value))
+	xml->priv->focus_widget = widget;
+}
+
 static void
 pixmap_set_build_insensitive (GladeXML *xml, GtkWidget *w,
 			      const char *name, const char *value)
@@ -94,10 +114,10 @@ pixmap_set_filename (GladeXML *xml, GtkWidget *w,
     gdk_pixbuf_render_pixmap_and_mask (pb, &pixmap, &bitmap, 127);
     gtk_pixmap_set (GTK_PIXMAP (w), pixmap, bitmap);
 
-    if (pixmap) gdk_pixmap_unref (pixmap);
-    if (bitmap) gdk_bitmap_unref (bitmap);
+    if (pixmap) g_object_unref (pixmap);
+    if (bitmap) g_object_unref (bitmap);
 
-    gdk_pixbuf_unref (pb);
+    g_object_unref (pb);
 }
 
 static void
@@ -840,6 +860,8 @@ colorseldlg_find_internal_child(GladeXML *xml, GtkWidget *parent,
 	return GTK_COLOR_SELECTION_DIALOG(parent)->cancel_button;
     if (!strcmp(childname, "help_button"))
 	return GTK_COLOR_SELECTION_DIALOG(parent)->help_button;
+    if (!strcmp(childname, "color_selection"))
+	return GTK_COLOR_SELECTION_DIALOG(parent)->colorsel;
     return NULL;
 }
 
@@ -857,6 +879,8 @@ fontseldlg_find_internal_child(GladeXML *xml, GtkWidget *parent,
 	return GTK_FONT_SELECTION_DIALOG(parent)->cancel_button;
     if (!strcmp(childname, "apply_button"))
 	return GTK_FONT_SELECTION_DIALOG(parent)->apply_button;
+    if (!strcmp(childname, "font_selection"))
+	return GTK_FONT_SELECTION_DIALOG(parent)->fontsel;
     return NULL;
 }
 
@@ -882,6 +906,9 @@ _glade_init_gtk_widgets(void)
 {
     glade_register_custom_prop (GTK_TYPE_WIDGET, "visible", set_visible);
     glade_register_custom_prop (GTK_TYPE_WIDGET, "tooltip", set_tooltip);
+    glade_register_custom_prop (GTK_TYPE_WIDGET, "has_default", set_has_default);
+    glade_register_custom_prop (GTK_TYPE_WIDGET, "has_focus", set_has_focus);
+
     glade_register_custom_prop (GTK_TYPE_PIXMAP, "build_insensitive", pixmap_set_build_insensitive);
     glade_register_custom_prop (GTK_TYPE_PIXMAP, "filename", pixmap_set_filename);
     glade_register_custom_prop (GTK_TYPE_PROGRESS, "format", progress_set_format);
